|PyJibe|
========

|PyPI Version| |Tests Status Linux| |Tests Status Win| |Coverage Status| |Docs Status|


**PyJibe** is a graphical end-user software for the analysis of atomic force
microscopy data.


Documentation
-------------

The documentation, including the code reference and examples, is available at
`pyjibe.readthedocs.io <https://pyjibe.readthedocs.io/en/stable/>`__.


Installation
------------

::

    pip install pyjibe


Testing
-------

::

    pip install -e .
    python setup.py test
    

.. |PyJibe| image:: https://raw.github.com/AFM-analysis/PyJibe/master/docs/logo/PyJibe.png
.. |PyPI Version| image:: https://img.shields.io/pypi/v/PyJibe.svg
   :target: https://pypi.python.org/pypi/PyJibe
.. |Tests Status Linux| image:: https://img.shields.io/travis/AFM-analysis/PyJibe.svg?label=tests_linux
   :target: https://travis-ci.org/AFM-analysis/PyJibe
.. |Tests Status Win| image:: https://img.shields.io/appveyor/ci/paulmueller/PyJibe?label=tests_win
   :target: https://ci.appveyor.com/project/paulmueller/PyJibe
.. |Coverage Status| image:: https://img.shields.io/codecov/c/github/AFM-analysis/PyJibe/master.svg
   :target: https://codecov.io/gh/AFM-analysis/PyJibe
.. |Docs Status| image:: https://readthedocs.org/projects/PyJibe/badge/?version=latest
   :target: https://readthedocs.org/projects/PyJibe/builds/

